"""
𐃏 Substrate
@generated file
(using datamodel-codegen)
"""


from __future__ import annotations

from typing import Any, Dict, List, Optional
from dataclasses import dataclass
from typing_extensions import Literal


@dataclass
class ErrorOut:
    """
    Future reference to ErrorOut
    """

    type: Literal["api_error", "invalid_request_error"]
    """
    (Future reference)
    The type of error returned.
    """
    message: str
    """
    (Future reference)
    A message providing more details about the error.
    """
    request_id: Optional[str] = None
    """
    (Future reference)
    A unique identifier for the request.
    """


@dataclass
class FutureRunCodeIn:
    """
    Future reference to FutureRunCodeIn
    """

    code: str
    """
    (Future reference)
    Code to execute.
    """
    args: Optional[List[str]] = None
    """
    (Future reference)
    List of command line arguments.
    """
    language: Literal["python", "typescript", "javascript"] = "python"
    """
    (Future reference)
    Interpreter to use.
    """


@dataclass
class FutureRunCodeOut:
    """
    Future reference to FutureRunCodeOut
    """

    json_output: Dict[str, Any]
    """
    (Future reference)
    `output` as parsed JSON. Print serialized json to `stdout` to receive JSON.
    """
    output: Optional[str] = None
    """
    (Future reference)
    Contents of `stdout` after executing the code.
    """
    error: Optional[str] = None
    """
    (Future reference)
    Contents of `stderr` after executing the code.
    """


@dataclass
class FutureGenerateTextIn:
    """
    Future reference to FutureGenerateTextIn
    """

    prompt: str
    """
    (Future reference)
    Input prompt.
    """
    temperature: float = 0.4
    """
    (Future reference)
    Sampling temperature to use. Higher values make the output more random, lower values make the output more deterministic.
    """
    max_tokens: Optional[int] = None
    """
    (Future reference)
    Maximum number of tokens to generate.
    """
    node: Literal[
        "Mistral7BInstruct",
        "Mixtral8x7BInstruct",
        "Llama3Instruct8B",
        "Llama3Instruct70B",
    ] = "Mistral7BInstruct"
    """
    (Future reference)
    Selected node.
    """


@dataclass
class FutureGenerateTextOut:
    """
    Future reference to FutureGenerateTextOut
    """

    text: str
    """
    (Future reference)
    Text response.
    """


@dataclass
class FutureGenerateJSONIn:
    """
    Future reference to FutureGenerateJSONIn
    """

    prompt: str
    """
    (Future reference)
    Input prompt.
    """
    json_schema: Dict[str, Any]
    """
    (Future reference)
    JSON schema to guide `json_object` response.
    """
    temperature: float = 0.4
    """
    (Future reference)
    Sampling temperature to use. Higher values make the output more random, lower values make the output more deterministic.
    """
    max_tokens: Optional[int] = None
    """
    (Future reference)
    Maximum number of tokens to generate.
    """
    node: Literal["Mistral7BInstruct", "Mixtral8x7BInstruct"] = "Mistral7BInstruct"
    """
    (Future reference)
    Selected node.
    """


@dataclass
class FutureGenerateJSONOut:
    """
    Future reference to FutureGenerateJSONOut
    """

    json_object: Optional[Dict[str, Any]] = None
    """
    (Future reference)
    JSON response.
    """
    text: Optional[str] = None
    """
    (Future reference)
    If the model output could not be parsed to JSON, this is the raw text output.
    """


@dataclass
class FutureMultiGenerateTextIn:
    """
    Future reference to FutureMultiGenerateTextIn
    """

    prompt: str
    """
    (Future reference)
    Input prompt.
    """
    num_choices: int
    """
    (Future reference)
    Number of choices to generate.
    """
    temperature: float = 0.4
    """
    (Future reference)
    Sampling temperature to use. Higher values make the output more random, lower values make the output more deterministic.
    """
    max_tokens: Optional[int] = None
    """
    (Future reference)
    Maximum number of tokens to generate.
    """
    node: Literal[
        "Mistral7BInstruct",
        "Mixtral8x7BInstruct",
        "Llama3Instruct8B",
        "Llama3Instruct70B",
    ] = "Mistral7BInstruct"
    """
    (Future reference)
    Selected node.
    """


@dataclass
class FutureMultiGenerateTextOut:
    """
    Future reference to FutureMultiGenerateTextOut
    """

    choices: List[FutureGenerateTextOut]
    """
    (Future reference)
    Response choices.
    """


@dataclass
class FutureBatchGenerateTextIn:
    """
    Future reference to FutureBatchGenerateTextIn
    """

    prompts: List[str]
    """
    (Future reference)
    Batch input prompts.
    """
    temperature: float = 0.4
    """
    (Future reference)
    Sampling temperature to use. Higher values make the output more random, lower values make the output more deterministic.
    """
    max_tokens: Optional[int] = None
    """
    (Future reference)
    Maximum number of tokens to generate.
    """


@dataclass
class FutureBatchGenerateTextOut:
    """
    Future reference to FutureBatchGenerateTextOut
    """

    outputs: List[FutureGenerateTextOut]
    """
    (Future reference)
    Batch outputs.
    """


@dataclass
class FutureMultiGenerateJSONIn:
    """
    Future reference to FutureMultiGenerateJSONIn
    """

    prompt: str
    """
    (Future reference)
    Input prompt.
    """
    json_schema: Dict[str, Any]
    """
    (Future reference)
    JSON schema to guide `json_object` response.
    """
    num_choices: int
    """
    (Future reference)
    Number of choices to generate.
    """
    temperature: float = 0.4
    """
    (Future reference)
    Sampling temperature to use. Higher values make the output more random, lower values make the output more deterministic.
    """
    max_tokens: Optional[int] = None
    """
    (Future reference)
    Maximum number of tokens to generate.
    """
    node: Literal["Mistral7BInstruct", "Mixtral8x7BInstruct"] = "Mistral7BInstruct"
    """
    (Future reference)
    Selected node.
    """


@dataclass
class FutureMultiGenerateJSONOut:
    """
    Future reference to FutureMultiGenerateJSONOut
    """

    choices: List[FutureGenerateJSONOut]
    """
    (Future reference)
    Response choices.
    """


@dataclass
class FutureBatchGenerateJSONIn:
    """
    Future reference to FutureBatchGenerateJSONIn
    """

    prompts: List[str]
    """
    (Future reference)
    Batch input prompts.
    """
    json_schema: Dict[str, Any]
    """
    (Future reference)
    JSON schema to guide `json_object` response.
    """
    temperature: float = 0.4
    """
    (Future reference)
    Sampling temperature to use. Higher values make the output more random, lower values make the output more deterministic.
    """
    max_tokens: Optional[int] = None
    """
    (Future reference)
    Maximum number of tokens to generate.
    """


@dataclass
class FutureBatchGenerateJSONOut:
    """
    Future reference to FutureBatchGenerateJSONOut
    """

    outputs: List[FutureGenerateJSONOut]
    """
    (Future reference)
    Batch outputs.
    """


@dataclass
class FutureMistral7BInstructIn:
    """
    Future reference to FutureMistral7BInstructIn
    """

    prompt: str
    """
    (Future reference)
    Input prompt.
    """
    num_choices: int = 1
    """
    (Future reference)
    Number of choices to generate.
    """
    json_schema: Optional[Dict[str, Any]] = None
    """
    (Future reference)
    JSON schema to guide response.
    """
    temperature: Optional[float] = None
    """
    (Future reference)
    Sampling temperature to use. Higher values make the output more random, lower values make the output more deterministic.
    """
    max_tokens: Optional[int] = None
    """
    (Future reference)
    Maximum number of tokens to generate.
    """


@dataclass
class Mistral7BInstructChoice:
    """
    Future reference to Mistral7BInstructChoice
    """

    text: Optional[str] = None
    """
    (Future reference)
    Text response, if `json_schema` was not provided.
    """
    json_object: Optional[Dict[str, Any]] = None
    """
    (Future reference)
    JSON response, if `json_schema` was provided.
    """


@dataclass
class FutureMistral7BInstructOut:
    """
    Future reference to FutureMistral7BInstructOut
    """

    choices: List[Mistral7BInstructChoice]
    """
    (Future reference)
    Response choices.
    """


@dataclass
class FutureMixtral8x7BInstructIn:
    """
    Future reference to FutureMixtral8x7BInstructIn
    """

    prompt: str
    """
    (Future reference)
    Input prompt.
    """
    num_choices: int = 1
    """
    (Future reference)
    Number of choices to generate.
    """
    json_schema: Optional[Dict[str, Any]] = None
    """
    (Future reference)
    JSON schema to guide response.
    """
    temperature: Optional[float] = None
    """
    (Future reference)
    Sampling temperature to use. Higher values make the output more random, lower values make the output more deterministic.
    """
    max_tokens: Optional[int] = None
    """
    (Future reference)
    Maximum number of tokens to generate.
    """


@dataclass
class Mixtral8x7BChoice:
    """
    Future reference to Mixtral8x7BChoice
    """

    text: Optional[str] = None
    """
    (Future reference)
    Text response, if `json_schema` was not provided.
    """
    json_object: Optional[Dict[str, Any]] = None
    """
    (Future reference)
    JSON response, if `json_schema` was provided.
    """


@dataclass
class FutureMixtral8x7BInstructOut:
    """
    Future reference to FutureMixtral8x7BInstructOut
    """

    choices: List[Mixtral8x7BChoice]
    """
    (Future reference)
    Response choices.
    """


@dataclass
class FutureLlama3Instruct8BIn:
    """
    Future reference to FutureLlama3Instruct8BIn
    """

    prompt: str
    """
    (Future reference)
    Input prompt.
    """
    num_choices: int = 1
    """
    (Future reference)
    Number of choices to generate.
    """
    temperature: Optional[float] = None
    """
    (Future reference)
    Sampling temperature to use. Higher values make the output more random, lower values make the output more deterministic.
    """
    max_tokens: Optional[int] = None
    """
    (Future reference)
    Maximum number of tokens to generate.
    """


@dataclass
class Llama3Instruct8BChoice:
    """
    Future reference to Llama3Instruct8BChoice
    """

    text: Optional[str] = None
    """
    (Future reference)
    Text response.
    """


@dataclass
class FutureLlama3Instruct8BOut:
    """
    Future reference to FutureLlama3Instruct8BOut
    """

    choices: List[Llama3Instruct8BChoice]
    """
    (Future reference)
    Response choices.
    """


@dataclass
class FutureLlama3Instruct70BIn:
    """
    Future reference to FutureLlama3Instruct70BIn
    """

    prompt: str
    """
    (Future reference)
    Input prompt.
    """
    num_choices: int = 1
    """
    (Future reference)
    Number of choices to generate.
    """
    temperature: Optional[float] = None
    """
    (Future reference)
    Sampling temperature to use. Higher values make the output more random, lower values make the output more deterministic.
    """
    max_tokens: Optional[int] = None
    """
    (Future reference)
    Maximum number of tokens to generate.
    """


@dataclass
class Llama3Instruct70BChoice:
    """
    Future reference to Llama3Instruct70BChoice
    """

    text: Optional[str] = None
    """
    (Future reference)
    Text response.
    """


@dataclass
class FutureLlama3Instruct70BOut:
    """
    Future reference to FutureLlama3Instruct70BOut
    """

    choices: List[Llama3Instruct70BChoice]
    """
    (Future reference)
    Response choices.
    """


@dataclass
class FutureGenerateTextVisionIn:
    """
    Future reference to FutureGenerateTextVisionIn
    """

    prompt: str
    """
    (Future reference)
    Text prompt.
    """
    image_uris: List[str]
    """
    (Future reference)
    Image prompts.
    """
    max_tokens: int = 800
    """
    (Future reference)
    Maximum number of tokens to generate.
    """


@dataclass
class FutureGenerateTextVisionOut:
    """
    Future reference to FutureGenerateTextVisionOut
    """

    text: str
    """
    (Future reference)
    Text response.
    """


@dataclass
class FutureFirellava13BIn:
    """
    Future reference to FutureFirellava13BIn
    """

    prompt: str
    """
    (Future reference)
    Text prompt.
    """
    image_uris: List[str]
    """
    (Future reference)
    Image prompts.
    """
    max_tokens: int = 800
    """
    (Future reference)
    Maximum number of tokens to generate.
    """


@dataclass
class FutureFirellava13BOut:
    """
    Future reference to FutureFirellava13BOut
    """

    text: str
    """
    (Future reference)
    Text response.
    """


@dataclass
class FutureGenerateImageIn:
    """
    Future reference to FutureGenerateImageIn
    """

    prompt: str
    """
    (Future reference)
    Text prompt.
    """
    store: Optional[str] = None
    """
    (Future reference)
    Use "hosted" to return an image URL hosted on Substrate. You can also provide a URL to a registered [file store](https://guides.substrate.run/guides/external-file-storage). If unset, the image data will be returned as a base64-encoded string.
    """


@dataclass
class FutureGenerateImageOut:
    """
    Future reference to FutureGenerateImageOut
    """

    image_uri: str
    """
    (Future reference)
    Base 64-encoded JPEG image bytes, or a hosted image url if `store` is provided.
    """


@dataclass
class FutureMultiGenerateImageIn:
    """
    Future reference to FutureMultiGenerateImageIn
    """

    prompt: str
    """
    (Future reference)
    Text prompt.
    """
    num_images: int
    """
    (Future reference)
    Number of images to generate.
    """
    store: Optional[str] = None
    """
    (Future reference)
    Use "hosted" to return an image URL hosted on Substrate. You can also provide a URL to a registered [file store](https://guides.substrate.run/guides/external-file-storage). If unset, the image data will be returned as a base64-encoded string.
    """


@dataclass
class FutureMultiGenerateImageOut:
    """
    Future reference to FutureMultiGenerateImageOut
    """

    outputs: List[FutureGenerateImageOut]
    """
    (Future reference)
    Generated images.
    """


@dataclass
class FutureStableDiffusionXLIn:
    """
    Future reference to FutureStableDiffusionXLIn
    """

    prompt: str
    """
    (Future reference)
    Text prompt.
    """
    num_images: int
    """
    (Future reference)
    Number of images to generate.
    """
    negative_prompt: Optional[str] = None
    """
    (Future reference)
    Negative input prompt.
    """
    steps: int = 30
    """
    (Future reference)
    Number of diffusion steps.
    """
    store: Optional[str] = None
    """
    (Future reference)
    Use "hosted" to return an image URL hosted on Substrate. You can also provide a URL to a registered [file store](https://guides.substrate.run/guides/external-file-storage). If unset, the image data will be returned as a base64-encoded string.
    """
    height: int = 1024
    """
    (Future reference)
    Height of output image, in pixels.
    """
    width: int = 1024
    """
    (Future reference)
    Width of output image, in pixels.
    """
    seeds: Optional[List[int]] = None
    """
    (Future reference)
    Seeds for deterministic generation. Default is a random seed.
    """
    guidance_scale: float = 7
    """
    (Future reference)
    Higher values adhere to the text prompt more strongly, typically at the expense of image quality.
    """


@dataclass
class StableDiffusionImage:
    """
    Future reference to StableDiffusionImage
    """

    image_uri: str
    """
    (Future reference)
    Base 64-encoded JPEG image bytes, or a hosted image url if `store` is provided.
    """
    seed: int
    """
    (Future reference)
    The random noise seed used for generation.
    """


@dataclass
class FutureStableDiffusionXLOut:
    """
    Future reference to FutureStableDiffusionXLOut
    """

    outputs: List[StableDiffusionImage]
    """
    (Future reference)
    Generated images.
    """


@dataclass
class FutureStableDiffusionXLLightningIn:
    """
    Future reference to FutureStableDiffusionXLLightningIn
    """

    prompt: str
    """
    (Future reference)
    Text prompt.
    """
    negative_prompt: Optional[str] = None
    """
    (Future reference)
    Negative input prompt.
    """
    num_images: int = 1
    """
    (Future reference)
    Number of images to generate.
    """
    store: Optional[str] = None
    """
    (Future reference)
    Use "hosted" to return an image URL hosted on Substrate. You can also provide a URL to a registered [file store](https://guides.substrate.run/guides/external-file-storage). If unset, the image data will be returned as a base64-encoded string.
    """
    height: int = 1024
    """
    (Future reference)
    Height of output image, in pixels.
    """
    width: int = 1024
    """
    (Future reference)
    Width of output image, in pixels.
    """
    seeds: Optional[List[int]] = None
    """
    (Future reference)
    Seeds for deterministic generation. Default is a random seed.
    """


@dataclass
class FutureStableDiffusionXLLightningOut:
    """
    Future reference to FutureStableDiffusionXLLightningOut
    """

    outputs: List[StableDiffusionImage]
    """
    (Future reference)
    Generated images.
    """


@dataclass
class FutureStableDiffusionXLIPAdapterIn:
    """
    Future reference to FutureStableDiffusionXLIPAdapterIn
    """

    prompt: str
    """
    (Future reference)
    Text prompt.
    """
    image_prompt_uri: str
    """
    (Future reference)
    Image prompt.
    """
    num_images: int
    """
    (Future reference)
    Number of images to generate.
    """
    ip_adapter_scale: float = 0.5
    """
    (Future reference)
    Controls the influence of the image prompt on the generated output.
    """
    negative_prompt: Optional[str] = None
    """
    (Future reference)
    Negative input prompt.
    """
    store: Optional[str] = None
    """
    (Future reference)
    Use "hosted" to return an image URL hosted on Substrate. You can also provide a URL to a registered [file store](https://guides.substrate.run/guides/external-file-storage). If unset, the image data will be returned as a base64-encoded string.
    """
    width: int = 1024
    """
    (Future reference)
    Width of output image, in pixels.
    """
    height: int = 1024
    """
    (Future reference)
    Height of output image, in pixels.
    """
    seeds: Optional[List[int]] = None
    """
    (Future reference)
    Random noise seeds. Default is random seeds for each generation.
    """


@dataclass
class FutureStableDiffusionXLIPAdapterOut:
    """
    Future reference to FutureStableDiffusionXLIPAdapterOut
    """

    outputs: List[StableDiffusionImage]
    """
    (Future reference)
    Generated images.
    """


@dataclass
class FutureStableDiffusionXLControlNetIn:
    """
    Future reference to FutureStableDiffusionXLControlNetIn
    """

    image_uri: str
    """
    (Future reference)
    Input image.
    """
    control_method: Literal["edge", "depth", "illusion"]
    """
    (Future reference)
    Strategy to control generation using the input image.
    """
    prompt: str
    """
    (Future reference)
    Text prompt.
    """
    num_images: int
    """
    (Future reference)
    Number of images to generate.
    """
    output_resolution: int = 1024
    """
    (Future reference)
    Resolution of the output image, in pixels.
    """
    negative_prompt: Optional[str] = None
    """
    (Future reference)
    Negative input prompt.
    """
    store: Optional[str] = None
    """
    (Future reference)
    Use "hosted" to return an image URL hosted on Substrate. You can also provide a URL to a registered [file store](https://guides.substrate.run/guides/external-file-storage). If unset, the image data will be returned as a base64-encoded string.
    """
    conditioning_scale: float = 0.5
    """
    (Future reference)
    Controls the influence of the input image on the generated output.
    """
    seeds: Optional[List[int]] = None
    """
    (Future reference)
    Random noise seeds. Default is random seeds for each generation.
    """


@dataclass
class FutureStableDiffusionXLControlNetOut:
    """
    Future reference to FutureStableDiffusionXLControlNetOut
    """

    outputs: List[StableDiffusionImage]
    """
    (Future reference)
    Generated images.
    """


@dataclass
class FutureGenerativeEditImageIn:
    """
    Future reference to FutureGenerativeEditImageIn
    """

    image_uri: str
    """
    (Future reference)
    Original image.
    """
    prompt: str
    """
    (Future reference)
    Text prompt.
    """
    mask_image_uri: Optional[str] = None
    """
    (Future reference)
    Mask image that controls which pixels are inpainted. If unset, the entire image is edited (image-to-image).
    """
    store: Optional[str] = None
    """
    (Future reference)
    Use "hosted" to return an image URL hosted on Substrate. You can also provide a URL to a registered [file store](https://guides.substrate.run/guides/external-file-storage). If unset, the image data will be returned as a base64-encoded string.
    """


@dataclass
class FutureGenerativeEditImageOut:
    """
    Future reference to FutureGenerativeEditImageOut
    """

    image_uri: str
    """
    (Future reference)
    Base 64-encoded JPEG image bytes, or a hosted image url if `store` is provided.
    """


@dataclass
class FutureMultiGenerativeEditImageIn:
    """
    Future reference to FutureMultiGenerativeEditImageIn
    """

    image_uri: str
    """
    (Future reference)
    Original image.
    """
    prompt: str
    """
    (Future reference)
    Text prompt.
    """
    num_images: int
    """
    (Future reference)
    Number of images to generate.
    """
    mask_image_uri: Optional[str] = None
    """
    (Future reference)
    Mask image that controls which pixels are edited (inpainting). If unset, the entire image is edited (image-to-image).
    """
    store: Optional[str] = None
    """
    (Future reference)
    Use "hosted" to return an image URL hosted on Substrate. You can also provide a URL to a registered [file store](https://guides.substrate.run/guides/external-file-storage). If unset, the image data will be returned as a base64-encoded string.
    """


@dataclass
class FutureMultiGenerativeEditImageOut:
    """
    Future reference to FutureMultiGenerativeEditImageOut
    """

    outputs: List[FutureGenerativeEditImageOut]
    """
    (Future reference)
    Generated images.
    """


@dataclass
class FutureStableDiffusionXLInpaintIn:
    """
    Future reference to FutureStableDiffusionXLInpaintIn
    """

    image_uri: str
    """
    (Future reference)
    Original image.
    """
    prompt: str
    """
    (Future reference)
    Text prompt.
    """
    num_images: int
    """
    (Future reference)
    Number of images to generate.
    """
    mask_image_uri: Optional[str] = None
    """
    (Future reference)
    Mask image that controls which pixels are edited (inpainting). If unset, the entire image is edited (image-to-image).
    """
    output_resolution: int = 1024
    """
    (Future reference)
    Resolution of the output image, in pixels.
    """
    negative_prompt: Optional[str] = None
    """
    (Future reference)
    Negative input prompt.
    """
    store: Optional[str] = None
    """
    (Future reference)
    Use "hosted" to return an image URL hosted on Substrate. You can also provide a URL to a registered [file store](https://guides.substrate.run/guides/external-file-storage). If unset, the image data will be returned as a base64-encoded string.
    """
    strength: float = 0.8
    """
    (Future reference)
    Controls the strength of the generation process.
    """
    seeds: Optional[List[int]] = None
    """
    (Future reference)
    Random noise seeds. Default is random seeds for each generation.
    """


@dataclass
class FutureStableDiffusionXLInpaintOut:
    """
    Future reference to FutureStableDiffusionXLInpaintOut
    """

    outputs: List[StableDiffusionImage]
    """
    (Future reference)
    Generated images.
    """


@dataclass
class BoundingBox:
    """
    Future reference to BoundingBox
    """

    x1: float
    """
    (Future reference)
    Top left corner x.
    """
    y1: float
    """
    (Future reference)
    Top left corner y.
    """
    x2: float
    """
    (Future reference)
    Bottom right corner x.
    """
    y2: float
    """
    (Future reference)
    Bottom right corner y.
    """


@dataclass
class Point:
    """
    Future reference to Point
    """

    x: int
    """
    (Future reference)
    X position.
    """
    y: int
    """
    (Future reference)
    Y position.
    """


@dataclass
class FutureFillMaskIn:
    """
    Future reference to FutureFillMaskIn
    """

    image_uri: str
    """
    (Future reference)
    Input image.
    """
    mask_image_uri: str
    """
    (Future reference)
    Mask image that controls which pixels are inpainted.
    """
    store: Optional[str] = None
    """
    (Future reference)
    Use "hosted" to return an image URL hosted on Substrate. You can also provide a URL to a registered [file store](https://guides.substrate.run/guides/external-file-storage). If unset, the image data will be returned as a base64-encoded string.
    """


@dataclass
class FutureFillMaskOut:
    """
    Future reference to FutureFillMaskOut
    """

    image_uri: str
    """
    (Future reference)
    Base 64-encoded JPEG image bytes, or a hosted image url if `store` is provided.
    """


@dataclass
class FutureBigLaMaIn:
    """
    Future reference to FutureBigLaMaIn
    """

    image_uri: str
    """
    (Future reference)
    Input image.
    """
    mask_image_uri: str
    """
    (Future reference)
    Mask image that controls which pixels are inpainted.
    """
    store: Optional[str] = None
    """
    (Future reference)
    Use "hosted" to return an image URL hosted on Substrate. You can also provide a URL to a registered [file store](https://guides.substrate.run/guides/external-file-storage). If unset, the image data will be returned as a base64-encoded string.
    """


@dataclass
class FutureBigLaMaOut:
    """
    Future reference to FutureBigLaMaOut
    """

    image_uri: str
    """
    (Future reference)
    Base 64-encoded JPEG image bytes, or a hosted image url if `store` is provided.
    """


@dataclass
class FutureRemoveBackgroundIn:
    """
    Future reference to FutureRemoveBackgroundIn
    """

    image_uri: str
    """
    (Future reference)
    Input image.
    """
    return_mask: bool = False
    """
    (Future reference)
    Return a mask image instead of the original content.
    """
    background_color: Optional[str] = None
    """
    (Future reference)
    Hex value background color. Transparent if unset.
    """
    store: Optional[str] = None
    """
    (Future reference)
    Use "hosted" to return an image URL hosted on Substrate. You can also provide a URL to a registered [file store](https://guides.substrate.run/guides/external-file-storage). If unset, the image data will be returned as a base64-encoded string.
    """


@dataclass
class FutureRemoveBackgroundOut:
    """
    Future reference to FutureRemoveBackgroundOut
    """

    image_uri: str
    """
    (Future reference)
    Base 64-encoded JPEG image bytes, or a hosted image url if `store` is provided.
    """


@dataclass
class FutureDISISNetIn:
    """
    Future reference to FutureDISISNetIn
    """

    image_uri: str
    """
    (Future reference)
    Input image.
    """
    store: Optional[str] = None
    """
    (Future reference)
    Use "hosted" to return an image URL hosted on Substrate. You can also provide a URL to a registered [file store](https://guides.substrate.run/guides/external-file-storage). If unset, the image data will be returned as a base64-encoded string.
    """


@dataclass
class FutureDISISNetOut:
    """
    Future reference to FutureDISISNetOut
    """

    image_uri: str
    """
    (Future reference)
    Base 64-encoded JPEG image bytes, or a hosted image url if `store` is provided.
    """


@dataclass
class FutureUpscaleImageIn:
    """
    Future reference to FutureUpscaleImageIn
    """

    image_uri: str
    """
    (Future reference)
    Input image.
    """
    store: Optional[str] = None
    """
    (Future reference)
    Use "hosted" to return an image URL hosted on Substrate. You can also provide a URL to a registered [file store](https://guides.substrate.run/guides/external-file-storage). If unset, the image data will be returned as a base64-encoded string.
    """


@dataclass
class FutureUpscaleImageOut:
    """
    Future reference to FutureUpscaleImageOut
    """

    image_uri: str
    """
    (Future reference)
    Base 64-encoded JPEG image bytes, or a hosted image url if `store` is provided.
    """


@dataclass
class FutureRealESRGANIn:
    """
    Future reference to FutureRealESRGANIn
    """

    image_uri: str
    """
    (Future reference)
    Input image.
    """
    store: Optional[str] = None
    """
    (Future reference)
    Use "hosted" to return an image URL hosted on Substrate. You can also provide a URL to a registered [file store](https://guides.substrate.run/guides/external-file-storage). If unset, the image data will be returned as a base64-encoded string.
    """


@dataclass
class FutureRealESRGANOut:
    """
    Future reference to FutureRealESRGANOut
    """

    image_uri: str
    """
    (Future reference)
    Base 64-encoded JPEG image bytes, or a hosted image url if `store` is provided.
    """


@dataclass
class FutureSegmentUnderPointIn:
    """
    Future reference to FutureSegmentUnderPointIn
    """

    image_uri: str
    """
    (Future reference)
    Input image.
    """
    point: Point
    """
    (Future reference)
    Point prompt.
    """
    store: Optional[str] = None
    """
    (Future reference)
    Use "hosted" to return an image URL hosted on Substrate. You can also provide a URL to a registered [file store](https://guides.substrate.run/guides/external-file-storage). If unset, the image data will be returned as a base64-encoded string.
    """


@dataclass
class FutureSegmentUnderPointOut:
    """
    Future reference to FutureSegmentUnderPointOut
    """

    mask_image_uri: str
    """
    (Future reference)
    Detected segments in 'mask image' format. Base 64-encoded JPEG image bytes, or a hosted image url if `store` is provided.
    """


@dataclass
class FutureSegmentAnythingIn:
    """
    Future reference to FutureSegmentAnythingIn
    """

    image_uri: str
    """
    (Future reference)
    Input image.
    """
    point_prompts: Optional[List[Point]] = None
    """
    (Future reference)
    Point prompts, to detect a segment under the point. One of `point_prompts` or `box_prompts` must be set.
    """
    box_prompts: Optional[List[BoundingBox]] = None
    """
    (Future reference)
    Box prompts, to detect a segment within the bounding box. One of `point_prompts` or `box_prompts` must be set.
    """
    store: Optional[str] = None
    """
    (Future reference)
    Use "hosted" to return an image URL hosted on Substrate. You can also provide a URL to a registered [file store](https://guides.substrate.run/guides/external-file-storage). If unset, the image data will be returned as a base64-encoded string.
    """


@dataclass
class FutureSegmentAnythingOut:
    """
    Future reference to FutureSegmentAnythingOut
    """

    mask_image_uri: str
    """
    (Future reference)
    Detected segments in 'mask image' format. Base 64-encoded JPEG image bytes, or a hosted image url if `store` is provided.
    """


@dataclass
class FutureTranscribeMediaIn:
    """
    Future reference to FutureTranscribeMediaIn
    """

    audio_uri: str
    """
    (Future reference)
    Input audio.
    """
    prompt: Optional[str] = None
    """
    (Future reference)
    Prompt to guide model on the content and context of input audio.
    """
    language: str = "en"
    """
    (Future reference)
    Language of input audio in [ISO-639-1](https://en.wikipedia.org/wiki/List_of_ISO_639_language_codes) format.
    """
    segment: bool = False
    """
    (Future reference)
    Segment the text into sentences with approximate timestamps.
    """
    align: bool = False
    """
    (Future reference)
    Align transcription to produce more accurate sentence-level timestamps and word-level timestamps. An array of word segments will be included in each sentence segment.
    """
    diarize: bool = False
    """
    (Future reference)
    Identify speakers for each segment. Speaker IDs will be included in each segment.
    """
    suggest_chapters: bool = False
    """
    (Future reference)
    Suggest automatic chapter markers.
    """


@dataclass
class TranscribedWord:
    """
    Future reference to TranscribedWord
    """

    word: str
    """
    (Future reference)
    Text of word.
    """
    start: Optional[float] = None
    """
    (Future reference)
    Start time of word, in seconds.
    """
    end: Optional[float] = None
    """
    (Future reference)
    End time of word, in seconds.
    """
    speaker: Optional[str] = None
    """
    (Future reference)
    ID of speaker, if `diarize` is enabled.
    """


@dataclass
class TranscribedSegment:
    """
    Future reference to TranscribedSegment
    """

    text: str
    """
    (Future reference)
    Text of segment.
    """
    start: float
    """
    (Future reference)
    Start time of segment, in seconds.
    """
    end: float
    """
    (Future reference)
    End time of segment, in seconds.
    """
    speaker: Optional[str] = None
    """
    (Future reference)
    ID of speaker, if `diarize` is enabled.
    """
    words: Optional[List[TranscribedWord]] = None
    """
    (Future reference)
    Aligned words, if `align` is enabled.
    """


@dataclass
class ChapterMarker:
    """
    Future reference to ChapterMarker
    """

    title: str
    """
    (Future reference)
    Chapter title.
    """
    start: float
    """
    (Future reference)
    Start time of chapter, in seconds.
    """


@dataclass
class FutureTranscribeMediaOut:
    """
    Future reference to FutureTranscribeMediaOut
    """

    text: str
    """
    (Future reference)
    Transcribed text.
    """
    segments: Optional[List[TranscribedSegment]] = None
    """
    (Future reference)
    Transcribed segments, if `segment` is enabled.
    """
    chapters: Optional[List[ChapterMarker]] = None
    """
    (Future reference)
    Chapter markers, if `suggest_chapters` is enabled.
    """


@dataclass
class FutureGenerateSpeechIn:
    """
    Future reference to FutureGenerateSpeechIn
    """

    text: str
    """
    (Future reference)
    Input text.
    """
    store: Optional[str] = None
    """
    (Future reference)
    Use "hosted" to return an audio URL hosted on Substrate. You can also provide a URL to a registered [file store](https://guides.substrate.run/guides/external-file-storage). If unset, the audio data will be returned as a base64-encoded string.
    """


@dataclass
class FutureGenerateSpeechOut:
    """
    Future reference to FutureGenerateSpeechOut
    """

    audio_uri: str
    """
    (Future reference)
    Base 64-encoded WAV audio bytes, or a hosted audio url if `store` is provided.
    """


@dataclass
class FutureXTTSV2In:
    """
    Future reference to FutureXTTSV2In
    """

    text: str
    """
    (Future reference)
    Input text.
    """
    audio_uri: Optional[str] = None
    """
    (Future reference)
    Reference audio used to synthesize the speaker. If unset, a default speaker voice will be used.
    """
    language: str = "en"
    """
    (Future reference)
    Language of input text. Supported languages: `en, de, fr, es, it, pt, pl, zh, ar, cs, ru, nl, tr, hu, ko`.
    """
    store: Optional[str] = None
    """
    (Future reference)
    Use "hosted" to return an audio URL hosted on Substrate. You can also provide a URL to a registered [file store](https://guides.substrate.run/guides/external-file-storage). If unset, the audio data will be returned as a base64-encoded string.
    """


@dataclass
class FutureXTTSV2Out:
    """
    Future reference to FutureXTTSV2Out
    """

    audio_uri: str
    """
    (Future reference)
    Base 64-encoded WAV audio bytes, or a hosted audio url if `store` is provided.
    """


@dataclass
class Embedding:
    """
    Future reference to Embedding
    """

    vector: List[float]
    """
    (Future reference)
    Embedding vector.
    """
    doc_id: Optional[str] = None
    """
    (Future reference)
    Vector store document ID.
    """
    metadata: Optional[Dict[str, Any]] = None
    """
    (Future reference)
    Vector store document metadata.
    """


@dataclass
class FutureEmbedTextIn:
    """
    Future reference to FutureEmbedTextIn
    """

    text: str
    """
    (Future reference)
    Text to embed.
    """
    collection_name: Optional[str] = None
    """
    (Future reference)
    Vector store name.
    """
    metadata: Optional[Dict[str, Any]] = None
    """
    (Future reference)
    Metadata that can be used to query the vector store. Ignored if `collection_name` is unset.
    """
    embedded_metadata_keys: Optional[List[str]] = None
    """
    (Future reference)
    Choose keys from `metadata` to embed with text.
    """
    doc_id: Optional[str] = None
    """
    (Future reference)
    Vector store document ID. Ignored if `store` is unset.
    """
    model: Literal["jina-v2", "clip"] = "jina-v2"
    """
    (Future reference)
    Selected embedding model.
    """


@dataclass
class FutureEmbedTextOut:
    """
    Future reference to FutureEmbedTextOut
    """

    embedding: Embedding
    """
    (Future reference)
    Generated embedding.
    """


@dataclass
class EmbedTextItem:
    """
    Future reference to EmbedTextItem
    """

    text: str
    """
    (Future reference)
    Text to embed.
    """
    metadata: Optional[Dict[str, Any]] = None
    """
    (Future reference)
    Metadata that can be used to query the vector store. Ignored if `collection_name` is unset.
    """
    doc_id: Optional[str] = None
    """
    (Future reference)
    Vector store document ID. Ignored if `collection_name` is unset.
    """


@dataclass
class FutureMultiEmbedTextIn:
    """
    Future reference to FutureMultiEmbedTextIn
    """

    items: List[EmbedTextItem]
    """
    (Future reference)
    Items to embed.
    """
    collection_name: Optional[str] = None
    """
    (Future reference)
    Vector store name.
    """
    embedded_metadata_keys: Optional[List[str]] = None
    """
    (Future reference)
    Choose keys from `metadata` to embed with text.
    """
    model: Literal["jina-v2", "clip"] = "jina-v2"
    """
    (Future reference)
    Selected embedding model.
    """


@dataclass
class FutureMultiEmbedTextOut:
    """
    Future reference to FutureMultiEmbedTextOut
    """

    embeddings: List[Embedding]
    """
    (Future reference)
    Generated embeddings.
    """


@dataclass
class FutureJinaV2In:
    """
    Future reference to FutureJinaV2In
    """

    items: List[EmbedTextItem]
    """
    (Future reference)
    Items to embed.
    """
    collection_name: Optional[str] = None
    """
    (Future reference)
    Vector store name.
    """
    embedded_metadata_keys: Optional[List[str]] = None
    """
    (Future reference)
    Choose keys from `metadata` to embed with text.
    """


@dataclass
class FutureJinaV2Out:
    """
    Future reference to FutureJinaV2Out
    """

    embeddings: List[Embedding]
    """
    (Future reference)
    Generated embeddings.
    """


@dataclass
class FutureEmbedImageIn:
    """
    Future reference to FutureEmbedImageIn
    """

    image_uri: str
    """
    (Future reference)
    Image to embed.
    """
    collection_name: Optional[str] = None
    """
    (Future reference)
    Vector store name.
    """
    doc_id: Optional[str] = None
    """
    (Future reference)
    Vector store document ID. Ignored if `collection_name` is unset.
    """
    model: Literal["clip"] = "clip"
    """
    (Future reference)
    Selected embedding model.
    """


@dataclass
class FutureEmbedImageOut:
    """
    Future reference to FutureEmbedImageOut
    """

    embedding: Embedding
    """
    (Future reference)
    Generated embedding.
    """


@dataclass
class EmbedImageItem:
    """
    Future reference to EmbedImageItem
    """

    image_uri: str
    """
    (Future reference)
    Image to embed.
    """
    doc_id: Optional[str] = None
    """
    (Future reference)
    Vector store document ID. Ignored if `collection_name` is unset.
    """


@dataclass
class EmbedTextOrImageItem:
    """
    Future reference to EmbedTextOrImageItem
    """

    image_uri: Optional[str] = None
    """
    (Future reference)
    Image to embed.
    """
    text: Optional[str] = None
    """
    (Future reference)
    Text to embed.
    """
    metadata: Optional[Dict[str, Any]] = None
    """
    (Future reference)
    Metadata that can be used to query the vector store. Ignored if `collection_name` is unset.
    """
    doc_id: Optional[str] = None
    """
    (Future reference)
    Vector store document ID. Ignored if `collection_name` is unset.
    """


@dataclass
class FutureMultiEmbedImageIn:
    """
    Future reference to FutureMultiEmbedImageIn
    """

    items: List[EmbedImageItem]
    """
    (Future reference)
    Items to embed.
    """
    collection_name: Optional[str] = None
    """
    (Future reference)
    Vector store name.
    """
    model: Literal["clip"] = "clip"
    """
    (Future reference)
    Selected embedding model.
    """


@dataclass
class FutureMultiEmbedImageOut:
    """
    Future reference to FutureMultiEmbedImageOut
    """

    embeddings: List[Embedding]
    """
    (Future reference)
    Generated embeddings.
    """


@dataclass
class FutureCLIPIn:
    """
    Future reference to FutureCLIPIn
    """

    items: List[EmbedTextOrImageItem]
    """
    (Future reference)
    Items to embed.
    """
    collection_name: Optional[str] = None
    """
    (Future reference)
    Vector store name.
    """
    embedded_metadata_keys: Optional[List[str]] = None
    """
    (Future reference)
    Choose keys from `metadata` to embed with text. Only applies to text items.
    """


@dataclass
class FutureCLIPOut:
    """
    Future reference to FutureCLIPOut
    """

    embeddings: List[Embedding]
    """
    (Future reference)
    Generated embeddings.
    """


@dataclass
class FutureCreateVectorStoreIn:
    """
    Future reference to FutureCreateVectorStoreIn
    """

    collection_name: str
    """
    (Future reference)
    Vector store name.
    """
    model: Literal["jina-v2", "clip"]
    """
    (Future reference)
    Selected embedding model.
    """
    m: int = 16
    """
    (Future reference)
    The max number of connections per layer for the index.
    """
    ef_construction: int = 64
    """
    (Future reference)
    The size of the dynamic candidate list for constructing the index graph.
    """
    metric: Literal["cosine", "l2", "inner"] = "inner"
    """
    (Future reference)
    The distance metric to construct the index with.
    """


@dataclass
class FutureCreateVectorStoreOut:
    """
    Future reference to FutureCreateVectorStoreOut
    """

    collection_name: str
    """
    (Future reference)
    Vector store name.
    """
    model: Literal["jina-v2", "clip"]
    """
    (Future reference)
    Selected embedding model.
    """
    m: int
    """
    (Future reference)
    The max number of connections per layer for the index.
    """
    ef_construction: int
    """
    (Future reference)
    The size of the dynamic candidate list for constructing the index graph.
    """
    metric: Literal["cosine", "l2", "inner"]
    """
    (Future reference)
    The distance metric to construct the index with.
    """


@dataclass
class FutureListVectorStoresIn:
    """
    Future reference to FutureListVectorStoresIn
    """

    pass


@dataclass
class FutureListVectorStoresOut:
    """
    Future reference to FutureListVectorStoresOut
    """

    items: Optional[List[FutureCreateVectorStoreOut]] = None
    """
    (Future reference)
    List of vector stores.
    """


@dataclass
class FutureDeleteVectorStoreIn:
    """
    Future reference to FutureDeleteVectorStoreIn
    """

    collection_name: str
    """
    (Future reference)
    Vector store name.
    """
    model: Literal["jina-v2", "clip"]
    """
    (Future reference)
    Selected embedding model.
    """


@dataclass
class FutureDeleteVectorStoreOut:
    """
    Future reference to FutureDeleteVectorStoreOut
    """

    collection_name: str
    """
    (Future reference)
    Vector store name.
    """
    model: Literal["jina-v2", "clip"]
    """
    (Future reference)
    Selected embedding model.
    """


@dataclass
class Vector:
    """
    Future reference to Vector
    """

    id: str
    """
    (Future reference)
    Document ID.
    """
    vector: List[float]
    """
    (Future reference)
    Embedding vector.
    """
    metadata: Dict[str, Any]
    """
    (Future reference)
    Document metadata.
    """


@dataclass
class FutureFetchVectorsIn:
    """
    Future reference to FutureFetchVectorsIn
    """

    collection_name: str
    """
    (Future reference)
    Vector store name.
    """
    model: Literal["jina-v2", "clip"]
    """
    (Future reference)
    Selected embedding model.
    """
    ids: List[str]
    """
    (Future reference)
    Document IDs to retrieve.
    """


@dataclass
class FutureFetchVectorsOut:
    """
    Future reference to FutureFetchVectorsOut
    """

    vectors: List[Vector]
    """
    (Future reference)
    Retrieved vectors.
    """


@dataclass
class FutureUpdateVectorsOut:
    """
    Future reference to FutureUpdateVectorsOut
    """

    count: int
    """
    (Future reference)
    Number of vectors modified.
    """


@dataclass
class FutureDeleteVectorsOut:
    """
    Future reference to FutureDeleteVectorsOut
    """

    count: int
    """
    (Future reference)
    Number of vectors modified.
    """


@dataclass
class UpdateVectorParams:
    """
    Future reference to UpdateVectorParams
    """

    id: str
    """
    (Future reference)
    Document ID.
    """
    vector: Optional[List[float]] = None
    """
    (Future reference)
    Embedding vector.
    """
    metadata: Optional[Dict[str, Any]] = None
    """
    (Future reference)
    Document metadata.
    """


@dataclass
class FutureUpdateVectorsIn:
    """
    Future reference to FutureUpdateVectorsIn
    """

    collection_name: str
    """
    (Future reference)
    Vector store name.
    """
    model: Literal["jina-v2", "clip"]
    """
    (Future reference)
    Selected embedding model.
    """
    vectors: List[UpdateVectorParams]
    """
    (Future reference)
    Vectors to upsert.
    """


@dataclass
class FutureDeleteVectorsIn:
    """
    Future reference to FutureDeleteVectorsIn
    """

    collection_name: str
    """
    (Future reference)
    Vector store name.
    """
    model: Literal["jina-v2", "clip"]
    """
    (Future reference)
    Selected embedding model.
    """
    ids: List[str]
    """
    (Future reference)
    Document IDs to delete.
    """


@dataclass
class FutureQueryVectorStoreIn:
    """
    Future reference to FutureQueryVectorStoreIn
    """

    collection_name: str
    """
    (Future reference)
    Vector store to query against.
    """
    model: Literal["jina-v2", "clip"]
    """
    (Future reference)
    Selected embedding model.
    """
    query_strings: Optional[List[str]] = None
    """
    (Future reference)
    Texts to embed and use for the query.
    """
    query_image_uris: Optional[List[str]] = None
    """
    (Future reference)
    Image URIs to embed and use for the query.
    """
    query_vectors: Optional[List[List[float]]] = None
    """
    (Future reference)
    Vectors to use for the query.
    """
    query_ids: Optional[List[str]] = None
    """
    (Future reference)
    Document IDs to use for the query.
    """
    top_k: int = 10
    """
    (Future reference)
    Number of results to return.
    """
    ef_search: int = 40
    """
    (Future reference)
    The size of the dynamic candidate list for searching the index graph.
    """
    include_values: bool = False
    """
    (Future reference)
    Include the values of the vectors in the response.
    """
    include_metadata: bool = False
    """
    (Future reference)
    Include the metadata of the vectors in the response.
    """
    filters: Optional[Dict[str, Any]] = None
    """
    (Future reference)
    Filter metadata by key-value pairs.
    """


@dataclass
class VectorStoreQueryResult:
    """
    Future reference to VectorStoreQueryResult
    """

    id: str
    """
    (Future reference)
    Document ID.
    """
    distance: float
    """
    (Future reference)
    Similarity score.
    """
    vector: Optional[List[float]] = None
    """
    (Future reference)
    Embedding vector.
    """
    metadata: Optional[Dict[str, Any]] = None
    """
    (Future reference)
    Document metadata.
    """


@dataclass
class FutureQueryVectorStoreOut:
    """
    Future reference to FutureQueryVectorStoreOut
    """

    results: List[List[VectorStoreQueryResult]]
    """
    (Future reference)
    Query results.
    """
    collection_name: Optional[str] = None
    """
    (Future reference)
    Vector store name.
    """
    model: Optional[Literal["jina-v2", "clip"]] = None
    """
    (Future reference)
    Selected embedding model.
    """
    metric: Optional[Literal["cosine", "l2", "inner"]] = None
    """
    (Future reference)
    The distance metric used for the query.
    """
